
import unittest
from hmjr import Entries

class TestSubCollections(unittest.TestCase):

    def testSubCollectionDates(self):
        data = Entries().withBook("708", max=5).dates()
        self.assertIsNotNone(data)

    def testSubCollectionIndexes(self):
        data = Entries().withBook("708", max=5).indexes()
        self.assertIsNotNone(data)

    def testSubCollectionHeaders(self):
        data = Entries().withBook("708", max=5).headers()
        self.assertIsNotNone(data)

    def testSubCollectionContent(self):
        data = Entries().withBook("708", max=5).content()
        self.assertIsNotNone(data)


if __name__ == '__main__':
    unittest.main()



from functools import cmp_to_key

class By:
    def header():
        return lambda a: a["header"]
    def date():
        return cmp_to_key(lambda a, b: -1 if len(a["dates"]) < 1 else 1 if len(b["dates"]) < 1 else 1 if a["minDate"]["year"] < b["minDate"]["year"] else -1 if a["minDate"]["year"] > b["maxDate"]["year"] else 1 if a["minDate"]["month"] < b["minDate"]["month"] else -1 if a["minDate"]["month"] > b["maxDate"]["month"] else 1 if a["minDate"]["day"] < b["maxDate"]["day"] else -1)




from python_graphql_client import GraphqlClient
import numpy as np

def splitIntoWords(str, badChars):
    return np.array(str.translate(str.maketrans( '', '', badChars)).split(" "))

def validateBook(book):
    strBook = str(book)
    while len(strBook) < 3:
        strBook = "0" + strBook
    return strBook

BAD_CHARS = "\""
DEFAULT_MAX = 50

class Entries:
    def __init__(self):
       self.client = GraphqlClient(endpoint="https://hmjrapi-prod.herokuapp.com/")

    # Sort the current entries with the given key function.
    # This mutates the order of stored entries.
    def sorted(self, key):
        try:
            self.results = sorted(self.results, key=key)
            return self
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of the result entry dictionaries.
    def entries(self):
        try:
            return np.array(self.results);
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of the result header strings.
    def headers(self):
        try:
            return np.array([i["header"] for i in self.results])
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of the result content strings.
    def content(self):
        try:
            return np.array([i["content"] for i in self.results])
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of the result date dictionaries.
    def dates(self):
        try:
            return np.array([d for i in self.results for d in i["dates"]])
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of the result index dictionaries.
    def indexes(self):
        try:
            return np.array([d for i in self.results for d in i["indexes"]])
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of all the words in all headers. Repetitions are allowed.
    def headerWords(self, badChars=BAD_CHARS):
        try:
            return splitIntoWords(' '.join(self.headers()), badChars)
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of all the words in all headers. Repetitions are allowed.
    def contentWords(self, badChars=BAD_CHARS):
        try:
            return splitIntoWords(' '.join(self.content()), badChars)
        except:
            print("No results found. Try running a query first.")

    # Return a numpy array of all the words in each entry. Equivalent to headerWords + contentWords
    def words(self, badChars=BAD_CHARS):
        try:
            return np.concatenate((self.headerWords(badChars),self.contentWords(badChars)))
        except:
            print("No results found. Try running a query first.")

    def associate(self, words):
        indexes = self.indexes()
        if indexes.any():
            containedStrs = [s["content"] for s in indexes for word in words if s["content"] is not None if word in s["content"]]
            words = [word for s in containedStrs for word in s.split(" ") ]
            return {word:words.count(word) for word in words}

    # Make a raw GQL query to the hmjrapi backend.
    def query(self, query, variables, name):
        try:
            self.results = self.client.execute(query=query,variables=variables)["data"][name]
        except:
            print("Query resulted in error: ")

    # Query entries with no criteria.
    def all(self, offset=0, max=DEFAULT_MAX):
        query = """
            query ($max: Float!, $offset: Float!) {
                entries(max: $max, offset: $offset) {
                    book
                    header
                    content
                    dates {
                        day
                        month
                        year
                        stringified
                        content
                    }
                    indexes {
                        book
                        page
                        content
                    }
                }
            }
        """
        variables = {"max": max,"offset": offset}
        self.query(query, variables, "entries")
        return self;

    # Query entries that surround a specific date.
    def withDate(self, date, max=DEFAULT_MAX):
        query = """
            query ($max: Float!, $date: DateInput!) {
                entriesByDate(max: $max, date: $date) {
                    book
                    header
                    content
                    dates {
                        day
                        month
                        year
                        stringified
                        content
                    }
                    indexes {
                        book
                        page
                        content
                    }
                }
            }
        """
        variables = {"max": max,"date": date}
        self.query(query, variables, "entriesByDate")
        return self;

    # Query entries that contain a specific keyword in their header/content.
    def withKeyword(self, keyword, max=DEFAULT_MAX):
        query = """
            query ($max: Float!, $keyword: [String!]!) {
                entriesByKeyword(max: $max, keyword: $keyword) {
                    book
                    header
                    content
                    dates {
                        day
                        month
                        year
                        stringified
                        content
                    }
                    indexes {
                        book
                        page
                        content
                    }
                }
            }
        """
        variables = {"max": max,"keyword": keyword}
        self.query(query, variables, "entriesByKeyword")
        return self


    # Query entries with a specific volume of the diaries.
    def withBook(self, book, max=DEFAULT_MAX):
        query = """
            query ($max: Float!, $book: [String!]!) {
                entriesByBook(max: $max, book: $book) {
                    book
                    header
                    content
                    dates {
                        day
                        month
                        year
                        stringified
                        content
                    }
                    indexes {
                        book
                        page
                        content
                    }
                }
            }
        """
        variables = {"max": max,"book": [validateBook(x) for x in book]}
        self.query(query, variables, "entriesByBook")
        return self

    def withBookBetween(self, minBook, maxBook, max=DEFAULT_MAX):
        return self.withBook([x for x in range(minBook, maxBook, 1)], max)






import unittest
from hmjr import Entries

class TestEntries(unittest.TestCase):

    def testQueryEntriesByDate(self):
        data = Entries().withDate({
            "day": 5,
            "month": 5,
            "year": 44
        }).results
        self.assertIsNotNone(data)

    def testQueryEntriesByKeyword(self):
        data = Entries().withKeyword("camp").results
        self.assertIsNotNone(data)

    def testQueryEntriesByBook(self):
        data = Entries().withBook("001").results
        self.assertIsNotNone(data)

    def testQueryEntriesAll(self):
        data = Entries().all().results
        self.assertIsNotNone(data)

if __name__ == '__main__':
    unittest.main()



import unittest
from hmjr import Entries
from hmjr import By

class TestEntries(unittest.TestCase):

    def testSortEntriesByHeader(self):
        data = Entries().withBook("708").sorted(By.header)
        self.assertIsNotNone(data)

    def testSortEntriesByDate(self):
        data = Entries().withBook("708").sorted(By.date)
        self.assertIsNotNone(data)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

VERSION = "0.0.6"
DESCRIPTION = "A collection of tools for analyzing the HMJR Collection."
LONG_DESCRIPTION = "A collection of tools for analyzing the HMJR Collection."

setup(
    name="hmjr",
    version=VERSION,
    author="Teddy Randby",
    author_email="tedrandby@gmail.com",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['python-graphql-client'],
    keywords=['archives','analysis'],
    url="https://github.com/TeddyRandby/hmjrPyTools",
    download_url="https://github.com/TeddyRandby/hmjrPyTools/archive/0.0.6.tar.gz",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
    ]
)

